==> k3d_0.4.3.0.orig.tar.gz: k3d-0.4.3.0/k3dsdk/ianimation_render_engine.h <==
#ifndef K3DSDK_IANIMATION_RENDER_ENGINE_H
#define K3DSDK_IANIMATION_RENDER_ENGINE_H

// K-3D
// Copyright (c) 1995-2004, Timothy M. Shead
//
// Contact: tshead@k-3d.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/** \file
		\brief Declares ianimation_render_engine, an abstract interface implemented by render engines
		\author Tim Shead (tshead@k-3d.com)
*/

#include "iunknown.h"

// Forward declarations
namespace boost { namespace filesystem { class path; } }

namespace k3d
{

/// Abstract interface implemented by render engines
class ianimation_render_engine :
	public virtual k3d::iunknown
{
public:
	virtual bool render_animation(const boost::filesystem::path& OutputImages, const bool ViewCompletedImages) = 0;

protected:
	ianimation_render_engine() {}
	ianimation_render_engine(const ianimation_render_engine&) {}
	ianimation_render_engine& operator = (const ianimation_render_engine&) { return *this; }
	virtual ~ianimation_render_engine() {}
};

} // namespace k3d

#endif // K3DSDK_IANIMATION_RENDER_ENGINE_H

==> k3d_0.5.0.35.orig.tar.gz: k3d-0.5.0.35/k3dsdk/ianimation_render_engine.h <==
#ifndef K3DSDK_IANIMATION_RENDER_ENGINE_H
#define K3DSDK_IANIMATION_RENDER_ENGINE_H

// K-3D
// Copyright (c) 1995-2004, Timothy M. Shead
//
// Contact: tshead@k-3d.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/** \file
		\author Tim Shead (tshead@k-3d.com)
*/

#include "iunknown.h"

namespace boost { namespace filesystem { class path; } }

namespace k3d
{

class icamera;
	
/// Abstract interface implemented by objects that can render a sequence of still images
class ianimation_render_engine :
	public virtual iunknown
{
public:
	virtual bool render_animation(icamera& Camera, const boost::filesystem::path& OutputImages, const bool ViewCompletedImages) = 0;

protected:
	ianimation_render_engine() {}
	ianimation_render_engine(const ianimation_render_engine&) {}
	ianimation_render_engine& operator = (const ianimation_render_engine&) { return *this; }
	virtual ~ianimation_render_engine() {}
};

} // namespace k3d

#endif // K3DSDK_IANIMATION_RENDER_ENGINE_H
